@@ -129,6 +129,7 @@ class ModelData(TestData):
         a get_<ORM-NAME> method and fallback to get_orm"""
         method_name, method = self._get_method(orm_class)
         kwargs.setdefault("orm_class", orm_class)
+        logger.debug(f"Running {method_name} for orm_class {orm_class.__name__}")
         return method(**kwargs)
 
     def _gets_method(self, orm_class, **kwargs):
@@ -142,6 +143,7 @@ class ModelData(TestData):
         a get_<ORM-MODELS-NAME> method and fallback to get_orms"""
         method_name, method = self._gets_method(orm_class)
         kwargs.setdefault("orm_class", orm_class)
+        logger.debug(f"Running {method_name} for orm_class {orm_class.__name__}")
         return method(**kwargs)
 
     def _create_method(self, orm_class, **kwargs):
@@ -155,6 +157,7 @@ class ModelData(TestData):
         a create_<ORM-NAME> method and fallback to create_orm"""
         method_name, method = self._create_method(orm_class)
         kwargs.setdefault("orm_class", orm_class)
+        logger.debug(f"Running {method_name} for orm_class {orm_class.__name__}")
         return method(**kwargs)
 
     def _creates_method(self, orm_class, **kwargs):
@@ -168,6 +171,7 @@ class ModelData(TestData):
         a create_<ORM-MODELS-NAME> method and fallback to create_orm"""
         method_name, method = self._creates_method(orm_class)
         kwargs.setdefault("orm_class", orm_class)
+        logger.debug(f"Running {method_name} for orm_class {orm_class.__name__}")
         return method(**kwargs)
 
     def _fields_method(self, orm_class, **kwargs):
@@ -181,6 +185,7 @@ class ModelData(TestData):
         a get_<ORM-NAME>_fields method and fallback to get_orm_fields"""
         method_name, method = self._fields_method(orm_class)
         kwargs.setdefault("orm_class", orm_class)
+        logger.debug(f"Running {method_name} for orm_class {orm_class.__name__}")
         return method(**kwargs)
 
     def _find_attr(self, method_name):
@@ -281,36 +286,54 @@ class ModelData(TestData):
     def assure_orm_refs(self, orm_class, **kwargs):
         """When creating an orm, they will often need foreign key values, this will
         go through any of the foreign key ref fields and create a foreign key if
-        it wasn't included
+        it wasn't included.
+
+        This is a recursive method, when it finds a ref_class it will assure that
+        ref's foreign keys before handling ref, this way all references all the
+        way down the stack can be generated for the top level so the same refs
+        can propogate all the way down the dependency chain
 
         :param orm_class: Orm
         :param **kwargs: orm_class's actual field name value will be checked and
             the ref's orm_class.model_name will be checked
-            * ignore_refs: bool, default False, if True then refs will not be checked
-            * require_fields: bool, default True, if True then create missing refs, if False
-                then refs won't be created and so if they are missing their fields
-                will not be populated
+            * ignore_refs: bool, default False, if True then refs will not be checked,
+                passed in refs will still be set
+            * require_fields: bool, default True, if True then create missing refs,
+                if False, then refs won't be created and so if they are missing
+                their fields will not be populated
         :returns: dict, the kwargs with ref field_name and ref orm_class.model_name
             will be included
         """
+        logger.debug(f"Assuring orm refs for orm_class {orm_class.__name__}")
         kwargs = self.assure_orm_field_names(orm_class, **kwargs)
-        if not kwargs.get("ignore_refs", False):
-            require_fields = kwargs.get("require_fields", True)
-            for field_name, field in orm_class.schema.fields.items():
-                if ref_class := field.ref:
-                    if require_fields or field.is_required() or self.yes():
-                        ref_field_name = ref_class.model_name
 
-                        if field_name in kwargs:
-                            if ref_field_name not in kwargs:
-                                kwargs[ref_field_name] = ref_class.query.eq_pk(kwargs[field_name]).one()
+        ignore_refs = kwargs.get("ignore_refs", False)
+        require_fields = kwargs.get("require_fields", True)
+        for field_name, field in orm_class.schema.fields.items():
+            if ref_class := field.ref:
+                ref_field_name = ref_class.model_name
 
-                        else:
-                            if ref_field_name in kwargs:
-                                kwargs[field_name] = kwargs[ref_field_name].pk
+                if field_name in kwargs:
+                    if ref_field_name not in kwargs:
+                        kwargs[ref_field_name] = ref_class.query.eq_pk(
+                            kwargs[field_name]
+                        ).one()
 
-                            else:
-                                kwargs[ref_field_name] = self._create(ref_class)
+                else:
+                    if ref_field_name in kwargs:
+                        kwargs[field_name] = kwargs[ref_field_name].pk
+
+                    else:
+                        if not ignore_refs:
+                            if require_fields or field.is_required() or self.yes():
+                                # handle all ref_class's refs before we handle
+                                # ref_class
+                                kwargs.update(self.assure_orm_refs(ref_class, **kwargs))
+
+                                kwargs[ref_field_name] = self._create(
+                                    ref_class,
+                                    **kwargs
+                                )
                                 kwargs[field_name] = kwargs[ref_field_name].pk
 
         return kwargs
