@@ -13,7 +13,6 @@ import math
 import inspect
 import time
 import re
-import weakref
 
 from datatypes.collections import ListIterator
 from datatypes import property as cachedproperty
@@ -58,14 +57,6 @@ class Iterator(ListIterator):
 
         self.reset()
 
-        # cleanup
-        weakref.finalize(self, self.__del__)
-
-    def __del__(self):
-        """Whenever this gets garbage collected close everything. This is also the
-        method for weakref.finalize"""
-        self.close()
-
     def has_more(self):
         """Return true if there are more results for this query if the query didn't
         have a LIMIT clause
@@ -98,17 +89,8 @@ class Iterator(ListIterator):
 
         return cursor
 
-    def close(self):
-        if "_cursor" in self.__dict__:
-            try:
-                self._cursor.close()
-
-            except Exception:
-                pass
-
     def reset(self):
         """put all the pieces together to build a generator of the results"""
-        self.close()
         self._cursor = None
         self._cursor_i = 0
 
